pub struct ConferenceData {
pub conference_id: String,
pub conference_solution: Option<ConferenceSolution>,
pub create_request: Option<CreateConferenceRequest>,
pub entry_points: Vec<EntryPoint>,
pub notes: String,
pub parameters: Option<ConferenceParameters>,
pub signature: String,
}Fields
conference_id: StringETag of the collection.
conference_solution: Option<ConferenceSolution>create_request: Option<CreateConferenceRequest>entry_points: Vec<EntryPoint>Information about individual conference entry points, such as URLs or phone numbers. All of them must belong to the same conference. Either conferenceSolution and at least one entryPoint, or createRequest is required.
notes: StringETag of the collection.
parameters: Option<ConferenceParameters>signature: StringETag of the collection.