pub struct CreateConferenceRequest {
pub conference_solution_key: Option<ConferenceSolutionKey>,
pub request_id: String,
pub status: Option<ConferenceRequestStatus>,
}Fields
conference_solution_key: Option<ConferenceSolutionKey>request_id: StringETag of the collection.
status: Option<ConferenceRequestStatus>Trait Implementations
Sourceimpl Clone for CreateConferenceRequest
impl Clone for CreateConferenceRequest
Sourcefn clone(&self) -> CreateConferenceRequest
fn clone(&self) -> CreateConferenceRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateConferenceRequest
impl Debug for CreateConferenceRequest
Sourceimpl<'de> Deserialize<'de> for CreateConferenceRequest
impl<'de> Deserialize<'de> for CreateConferenceRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateConferenceRequest
impl JsonSchema for CreateConferenceRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CreateConferenceRequest
impl PartialEq for CreateConferenceRequest
Sourceimpl Serialize for CreateConferenceRequest
impl Serialize for CreateConferenceRequest
impl StructuralPartialEq for CreateConferenceRequest