pub struct Event {Show 39 fields
pub anyone_can_add_self: bool,
pub attachments: Vec<EventAttachment>,
pub attendees: Vec<EventAttendee>,
pub attendees_omitted: bool,
pub color_id: String,
pub conference_data: Option<ConferenceData>,
pub created: Option<DateTime<Utc>>,
pub creator: Option<Creator>,
pub description: String,
pub end: Option<EventDateTime>,
pub end_time_unspecified: bool,
pub etag: String,
pub event_type: String,
pub extended_properties: Option<ExtendedProperties>,
pub gadget: Option<Gadget>,
pub guests_can_invite_others: bool,
pub guests_can_modify: bool,
pub guests_can_see_other_guests: bool,
pub hangout_link: String,
pub html_link: String,
pub i_cal_uid: String,
pub id: String,
pub kind: String,
pub location: String,
pub locked: bool,
pub organizer: Option<Organizer>,
pub original_start_time: Option<EventDateTime>,
pub private_copy: bool,
pub recurrence: Vec<String>,
pub recurring_event_id: String,
pub reminders: Option<Reminders>,
pub sequence: i64,
pub source: Option<Source>,
pub start: Option<EventDateTime>,
pub status: String,
pub summary: String,
pub transparency: String,
pub updated: Option<DateTime<Utc>>,
pub visibility: String,
}Fields
anyone_can_add_self: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
attachments: Vec<EventAttachment>File attachments for the event. Currently only Google Drive attachments are supported. In order to modify attachments the supportsAttachments request parameter should be set to true. There can be at most 25 attachments per event,
attendees: Vec<EventAttendee>The attendees of the event. See the Events with attendees guide for more information on scheduling events with other calendar users. Service accounts need to use domain-wide delegation of authority to populate the attendee list.
attendees_omitted: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
color_id: StringETag of the collection.
conference_data: Option<ConferenceData>created: Option<DateTime<Utc>>Last modification time of the color palette (as a RFC3339 timestamp). Read-only.
creator: Option<Creator>The creator of the event. Read-only.
description: StringETag of the collection.
end: Option<EventDateTime>end_time_unspecified: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
etag: StringETag of the collection.
event_type: StringETag of the collection.
extended_properties: Option<ExtendedProperties>Extended properties of the event.
gadget: Option<Gadget>A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
guests_can_invite_others: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
guests_can_modify: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
guests_can_see_other_guests: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
hangout_link: StringETag of the collection.
html_link: StringETag of the collection.
i_cal_uid: StringETag of the collection.
id: StringETag of the collection.
kind: StringETag of the collection.
location: StringETag of the collection.
locked: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
organizer: Option<Organizer>The organizer of the event. If the organizer is also an attendee, this is indicated with a separate entry in attendees with the organizer field set to True. To change the organizer, use the move operation. Read-only, except when importing an event.
original_start_time: Option<EventDateTime>private_copy: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
recurrence: Vec<String>The types of conference solutions that are supported for this calendar. The possible values are:
- “eventHangout”
- “eventNamedHangout”
- “hangoutsMeet” Optional.
recurring_event_id: StringETag of the collection.
reminders: Option<Reminders>Information about the event’s reminders for the authenticated user.
sequence: i64Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional.
source: Option<Source>Source from which the event was created. For example, a web page, an email message or any document identifiable by an URL with HTTP or HTTPS scheme. Can only be seen or modified by the creator of the event.
start: Option<EventDateTime>status: StringETag of the collection.
summary: StringETag of the collection.
transparency: StringETag of the collection.
updated: Option<DateTime<Utc>>Last modification time of the color palette (as a RFC3339 timestamp). Read-only.
visibility: StringETag of the collection.