pub struct EventAttendee {
pub additional_guests: i64,
pub comment: String,
pub display_name: String,
pub email: String,
pub id: String,
pub optional: bool,
pub organizer: bool,
pub resource: bool,
pub response_status: String,
pub self_: bool,
}Fields
additional_guests: i64Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional.
comment: StringETag of the collection.
display_name: StringETag of the collection.
email: StringETag of the collection.
id: StringETag of the collection.
optional: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
organizer: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
resource: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.
response_status: StringETag of the collection.
self_: boolWhether this calendar list entry has been deleted from the calendar list. Read-only. Optional. The default is False.