pub struct FreeBusyRequest {
pub calendar_expansion_max: i64,
pub group_expansion_max: i64,
pub items: Vec<FreeBusyRequestItem>,
pub time_max: Option<DateTime<Utc>>,
pub time_min: Option<DateTime<Utc>>,
pub time_zone: String,
}Fields
calendar_expansion_max: i64Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional.
group_expansion_max: i64Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional.
items: Vec<FreeBusyRequestItem>List of calendars and/or groups to query.
time_max: Option<DateTime<Utc>>Last modification time of the color palette (as a RFC3339 timestamp). Read-only.
time_min: Option<DateTime<Utc>>Last modification time of the color palette (as a RFC3339 timestamp). Read-only.
time_zone: StringETag of the collection.