pub struct Gadget {
pub display: String,
pub height: i64,
pub icon_link: String,
pub link: String,
pub preferences: String,
pub title: String,
pub type_: String,
pub width: i64,
}Expand description
A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
Fields
display: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
height: i64A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
icon_link: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
link: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
preferences: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
title: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
type_: StringA gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.
width: i64A gadget that extends this event. Gadgets are deprecated; this structure is instead only used for returning birthday calendar metadata.